package VMOMI::HostInternetScsiHbaNetworkBindingSupportType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
